/*
 * Copyright 2020 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// SWIG input file of the 'blast' module

%feature("autodoc","1");

%module(docstring=
"'blastw' module: Viscous inviscid interaction for blast 2021-2022
(c) ULiege - A&M",
threads="1"
) blastw
%{

#include "blast.h"
#include "DBoundaryLayer.h"

#include "fwkw.h"
#include "tboxw.h"
#include "blastw.h"

%}


%include "fwkw.swg"

// ----------- MODULES UTILISES ------------
%import "tboxw.i"

// ----------- blast CLASSES ----------------
%include "blast.h"

%shared_ptr(blast::BoundaryLayer);
%include "DBoundaryLayer.h"

%shared_ptr(blast::Driver);
%immutable blast::Driver::Re; // read-only variable (no setter)
%immutable blast::Driver::Cdt;
%immutable blast::Driver::Cdt_sec;
%immutable blast::Driver::Cdf;
%immutable blast::Driver::Cdf_sec;
%immutable blast::Driver::Cdp;
%immutable blast::Driver::Cdp_sec;
%immutable blast::Driver::CFL0;
%immutable blast::Driver::verbose;
%include "DDriver.h"

%shared_ptr(blast::CoupledAdjoint);
%immutable blast::CoupledAdjoint::tdCl_AoA;
%immutable blast::CoupledAdjoint::tdCd_AoA;
%include "DCoupledAdjoint.h"
